package com.dzeio.openhealth

import android.app.Application
import android.content.Intent
import android.content.SharedPreferences
import android.util.Log
import androidx.preference.PreferenceManager
import com.dzeio.openhealth.ui.ErrorActivity
import com.google.android.material.color.DynamicColors
import dagger.hilt.android.HiltAndroidApp
import java.util.Locale

@HiltAndroidApp
class Application : Application() {
    companion object {
        const val TAG = "OpenHealth"
    }

    override fun onCreate() {
        super.onCreate()

        // Application Error Handling
        Thread.setDefaultUncaughtExceptionHandler { paramThread, paramThrowable ->
            //Log error to logcat if it wasn't done before
            Log.e(TAG, "Error, ${paramThread.id}", paramThrowable)

            // send use to the Error Activity
            val intent = Intent(applicationContext, ErrorActivity::class.java)

            intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
            intent.putExtra("error", paramThrowable.stackTraceToString())
            startActivity(intent)

            return@setDefaultUncaughtExceptionHandler
        }

        // Android Dynamics Colors
        DynamicColors.applyToActivitiesIfAvailable(this)

        // Change application Language based on setting
        val preferences: SharedPreferences = PreferenceManager.getDefaultSharedPreferences(this)
        val lang = preferences.getString("global_language", Locale.getDefault().language)
        val locale = Locale(lang)
        Locale.setDefault(locale)

//        val overrideConfiguration = baseContext.resources.configuration
//        overrideConfiguration.locale = locale
//        val context: Context = createConfigurationContext(overrideConfiguration)
//        val resources: Resources = context.resources
    }

    /**
     * SharedPreferences Key
     */
    object Settings {
    }
}
