package com.dzeio.openhealth.extensions

import android.app.Activity
import android.content.Intent
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.dzeio.openhealth.data.weight.Weight

/**
 * Extension Schema
 *
 * Version: 0.1.0
 */
interface Extension {

    data class ImportState<T>(
        val state: States = States.WIP,
        val list: List<T> = ArrayList()
    )

    enum class States {
        WIP,
        DONE,
        CANCELLED
    }

    enum class Data {
        /**
         * Special case to handle basic errors from other activities
         */
        NOTHING,
        WEIGHT,
        STEPS

        /**
         * Google Fit:
         *
         * STEP_COUNT_CUMULATIVE
         * ACTIVITY_SEGMENT
         * SLEEP_SEGMENT
         * CALORIES_EXPENDED
         * BASAL_METABOLIC_RATE
         * POWER_SAMPLE
         * HEART_RATE_BPM
         * LOCATION_SAMPLE
         */
    }


    val permissions: Array<String>?

    val permissionsText: String?

    /**
     * the Source ID
     *
     * DO NOT CHANGE IT AFTER THE EXTENSION IS IN PRODUCTION
     */
    val id: String

    /**
     * The Extension Display Name
     */
    val name: String

    /**
     * Initialize hte Extension
     *
     * It is run Before any functions is launched and after events handlers are set
     */
    fun init(activity: Activity): Array<Data>

    /**
     * A status shown on the extension list page
     */
    fun getStatus(): String {
        return "No Status set..."
    }

    /**
     * Function that will check
     */
    fun isAvailable(): Boolean

    /**
     * return if the extension is already connected to remote of not
     */
    fun isConnected(): Boolean

    fun connect(): LiveData<States> {
        return MutableLiveData(States.DONE)
    }

    fun importWeight(): LiveData<ImportState<Weight>> {
        return MutableLiveData(ImportState(States.DONE))
    }

    /**
     * function run when outgoing sync is enabled and new value is added
     * or manual export is launched
     */
    fun exportWeight(weight: Weight): LiveData<States> {
        return MutableLiveData(States.DONE)
    }

    /**
     * Activity Events
     */

    /**
     * Same as Activity/Fragment onActivityResult
     */
    fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {}
}
