package com.dzeio.openhealth.ui

import android.content.ActivityNotFoundException
import android.content.Intent
import android.net.Uri
import android.os.Build
import android.os.Bundle
import android.view.LayoutInflater
import android.widget.Toast
import com.dzeio.openhealth.Application
import com.dzeio.openhealth.BuildConfig
import com.dzeio.openhealth.core.BaseActivity
import com.dzeio.openhealth.databinding.ActivityErrorBinding
import dagger.hilt.android.AndroidEntryPoint

@AndroidEntryPoint
class ErrorActivity : BaseActivity<ActivityErrorBinding>() {

    companion object {
        const val TAG = "${Application.TAG}/ErrorActivity"
    }

    override val bindingInflater: (LayoutInflater) -> ActivityErrorBinding =
        ActivityErrorBinding::inflate

    override fun onCreated(savedInstanceState: Bundle?) {
        super.onCreated(savedInstanceState)

        val params = intent

        val data = params.getStringExtra("error")

        // Get Application datas
        val deviceToReport = if (Build.DEVICE.contains(Build.MANUFACTURER)) Build.DEVICE else "${Build.MANUFACTURER} ${Build.DEVICE}"

        val infos = """
            Application ID: ${BuildConfig.APPLICATION_ID}
            Version Code: ${BuildConfig.VERSION_CODE}
            Version Name: ${BuildConfig.VERSION_NAME}
            
            Android ${Build.VERSION.RELEASE} SDK ${Build.VERSION.SDK_INT}
            Model: $deviceToReport ${Build.MODEL}
        """.trimIndent()

        // merge our texts
        val reportText = infos + "\n\n" + data

        // put it in the textView
        binding.errorText.text = reportText

        // Handle the Quit button
        binding.errorQuit.setOnClickListener {
            finish()
        }

        // Handle the Email Button
        binding.errorSubmitEmail.setOnClickListener {

            // Create Intent
            val intent = Intent(Intent.ACTION_SEND)
            intent.data = Uri.parse("mailto:")
            intent.type = "text/plain"
            intent.putExtra(Intent.EXTRA_EMAIL, arrayOf("report.openhealth@dzeio.com"))
            intent.putExtra(Intent.EXTRA_SUBJECT, "Error report for application crash")
            intent.putExtra(Intent.EXTRA_TEXT, "Send Report Email\n$reportText")

            try {
                startActivity(Intent.createChooser(intent, "Send Report Email..."))
            } catch (e: ActivityNotFoundException) {
                Toast.makeText(this, "Not Email client found :(", Toast.LENGTH_LONG).show()
            }
        }

        // Handle the GitHub Button
        binding.errorSubmitGithub.setOnClickListener {

            // Build URL
            val url = "https://github.com/dzeiocom/OpenHealth/issues/new?title=Application Error&body=$reportText"

            try {
                startActivity(
                    Intent(Intent.ACTION_VIEW, Uri.parse(url))
                )
            } catch (e: ActivityNotFoundException) {
                Toast.makeText(this, "No Web Browser found :(", Toast.LENGTH_LONG).show()
            }
        }

    }
}
